# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetIdpCatalogEntityResult',
    'AwaitableGetIdpCatalogEntityResult',
    'get_idp_catalog_entity',
    'get_idp_catalog_entity_output',
]

@pulumi.output_type
class GetIdpCatalogEntityResult:
    """
    A collection of values returned by getIdpCatalogEntity.
    """
    def __init__(__self__, git_details=None, id=None, identifier=None, kind=None, org_id=None, project_id=None, yaml=None):
        if git_details and not isinstance(git_details, list):
            raise TypeError("Expected argument 'git_details' to be a list")
        pulumi.set(__self__, "git_details", git_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        pulumi.set(__self__, "kind", kind)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if yaml and not isinstance(yaml, str):
            raise TypeError("Expected argument 'yaml' to be a str")
        pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Sequence['outputs.GetIdpCatalogEntityGitDetailResult']:
        """
        Contains Git Information for importing entities from Git
        """
        return pulumi.get(self, "git_details")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> _builtins.str:
        """
        Kind of the catalog entity
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> _builtins.str:
        """
        YAML definition of the catalog entity
        """
        return pulumi.get(self, "yaml")


class AwaitableGetIdpCatalogEntityResult(GetIdpCatalogEntityResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIdpCatalogEntityResult(
            git_details=self.git_details,
            id=self.id,
            identifier=self.identifier,
            kind=self.kind,
            org_id=self.org_id,
            project_id=self.project_id,
            yaml=self.yaml)


def get_idp_catalog_entity(identifier: Optional[_builtins.str] = None,
                           kind: Optional[_builtins.str] = None,
                           org_id: Optional[_builtins.str] = None,
                           project_id: Optional[_builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIdpCatalogEntityResult:
    """
    Data source for retrieving Harness catalog entities.


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str kind: Kind of the catalog entity
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['kind'] = kind
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getIdpCatalogEntity:getIdpCatalogEntity', __args__, opts=opts, typ=GetIdpCatalogEntityResult).value

    return AwaitableGetIdpCatalogEntityResult(
        git_details=pulumi.get(__ret__, 'git_details'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        kind=pulumi.get(__ret__, 'kind'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        yaml=pulumi.get(__ret__, 'yaml'))
def get_idp_catalog_entity_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                  kind: Optional[pulumi.Input[_builtins.str]] = None,
                                  org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIdpCatalogEntityResult]:
    """
    Data source for retrieving Harness catalog entities.


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str kind: Kind of the catalog entity
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['kind'] = kind
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getIdpCatalogEntity:getIdpCatalogEntity', __args__, opts=opts, typ=GetIdpCatalogEntityResult)
    return __ret__.apply(lambda __response__: GetIdpCatalogEntityResult(
        git_details=pulumi.get(__response__, 'git_details'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        kind=pulumi.get(__response__, 'kind'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        yaml=pulumi.get(__response__, 'yaml')))
