# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetConnectorCustomSecretManagerResult',
    'AwaitableGetConnectorCustomSecretManagerResult',
    'get_connector_custom_secret_manager',
    'get_connector_custom_secret_manager_output',
]

@pulumi.output_type
class GetConnectorCustomSecretManagerResult:
    """
    A collection of values returned by getConnectorCustomSecretManager.
    """
    def __init__(__self__, delegate_selectors=None, description=None, id=None, identifier=None, name=None, on_delegate=None, org_id=None, project_id=None, ssh_secret_ref=None, tags=None, target_host=None, template_inputs=None, template_ref=None, timeout=None, type=None, version_label=None, working_directory=None):
        if delegate_selectors and not isinstance(delegate_selectors, list):
            raise TypeError("Expected argument 'delegate_selectors' to be a list")
        pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if on_delegate and not isinstance(on_delegate, bool):
            raise TypeError("Expected argument 'on_delegate' to be a bool")
        pulumi.set(__self__, "on_delegate", on_delegate)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if ssh_secret_ref and not isinstance(ssh_secret_ref, str):
            raise TypeError("Expected argument 'ssh_secret_ref' to be a str")
        pulumi.set(__self__, "ssh_secret_ref", ssh_secret_ref)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if target_host and not isinstance(target_host, str):
            raise TypeError("Expected argument 'target_host' to be a str")
        pulumi.set(__self__, "target_host", target_host)
        if template_inputs and not isinstance(template_inputs, list):
            raise TypeError("Expected argument 'template_inputs' to be a list")
        pulumi.set(__self__, "template_inputs", template_inputs)
        if template_ref and not isinstance(template_ref, str):
            raise TypeError("Expected argument 'template_ref' to be a str")
        pulumi.set(__self__, "template_ref", template_ref)
        if timeout and not isinstance(timeout, int):
            raise TypeError("Expected argument 'timeout' to be a int")
        pulumi.set(__self__, "timeout", timeout)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if version_label and not isinstance(version_label, str):
            raise TypeError("Expected argument 'version_label' to be a str")
        pulumi.set(__self__, "version_label", version_label)
        if working_directory and not isinstance(working_directory, str):
            raise TypeError("Expected argument 'working_directory' to be a str")
        pulumi.set(__self__, "working_directory", working_directory)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[Sequence[_builtins.str]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="onDelegate")
    def on_delegate(self) -> _builtins.bool:
        """
        Specifies whether the secrets manager runs on a Harness delegate.
        """
        return pulumi.get(self, "on_delegate")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="sshSecretRef")
    def ssh_secret_ref(self) -> _builtins.str:
        """
        SSH secret reference for the custom secrets manager, Computed if 'on_delegate' is false.
        """
        return pulumi.get(self, "ssh_secret_ref")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="targetHost")
    def target_host(self) -> _builtins.str:
        """
        Host where the custom secrets manager is located, Computed if 'on_delegate' is false.
        """
        return pulumi.get(self, "target_host")

    @_builtins.property
    @pulumi.getter(name="templateInputs")
    def template_inputs(self) -> Sequence['outputs.GetConnectorCustomSecretManagerTemplateInputResult']:
        return pulumi.get(self, "template_inputs")

    @_builtins.property
    @pulumi.getter(name="templateRef")
    def template_ref(self) -> _builtins.str:
        """
        Reference to the template used for managing secrets.
        """
        return pulumi.get(self, "template_ref")

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> _builtins.int:
        """
        Timeout in seconds for secrets management operations.
        """
        return pulumi.get(self, "timeout")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Type of the custom secrets manager, typically set to 'CustomSecretManager'.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="versionLabel")
    def version_label(self) -> _builtins.str:
        """
        Version identifier of the secrets management template.
        """
        return pulumi.get(self, "version_label")

    @_builtins.property
    @pulumi.getter(name="workingDirectory")
    def working_directory(self) -> _builtins.str:
        """
        The working directory for operations, Computed if 'on_delegate' is false.
        """
        return pulumi.get(self, "working_directory")


class AwaitableGetConnectorCustomSecretManagerResult(GetConnectorCustomSecretManagerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConnectorCustomSecretManagerResult(
            delegate_selectors=self.delegate_selectors,
            description=self.description,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            on_delegate=self.on_delegate,
            org_id=self.org_id,
            project_id=self.project_id,
            ssh_secret_ref=self.ssh_secret_ref,
            tags=self.tags,
            target_host=self.target_host,
            template_inputs=self.template_inputs,
            template_ref=self.template_ref,
            timeout=self.timeout,
            type=self.type,
            version_label=self.version_label,
            working_directory=self.working_directory)


def get_connector_custom_secret_manager(delegate_selectors: Optional[Sequence[_builtins.str]] = None,
                                        identifier: Optional[_builtins.str] = None,
                                        name: Optional[_builtins.str] = None,
                                        org_id: Optional[_builtins.str] = None,
                                        project_id: Optional[_builtins.str] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConnectorCustomSecretManagerResult:
    """
    Datasource for looking up a Custom Secret Manager connector.


    :param Sequence[_builtins.str] delegate_selectors: Tags to filter delegates for connection.
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['delegateSelectors'] = delegate_selectors
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getConnectorCustomSecretManager:getConnectorCustomSecretManager', __args__, opts=opts, typ=GetConnectorCustomSecretManagerResult).value

    return AwaitableGetConnectorCustomSecretManagerResult(
        delegate_selectors=pulumi.get(__ret__, 'delegate_selectors'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        on_delegate=pulumi.get(__ret__, 'on_delegate'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        ssh_secret_ref=pulumi.get(__ret__, 'ssh_secret_ref'),
        tags=pulumi.get(__ret__, 'tags'),
        target_host=pulumi.get(__ret__, 'target_host'),
        template_inputs=pulumi.get(__ret__, 'template_inputs'),
        template_ref=pulumi.get(__ret__, 'template_ref'),
        timeout=pulumi.get(__ret__, 'timeout'),
        type=pulumi.get(__ret__, 'type'),
        version_label=pulumi.get(__ret__, 'version_label'),
        working_directory=pulumi.get(__ret__, 'working_directory'))
def get_connector_custom_secret_manager_output(delegate_selectors: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                                               identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                               name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                               org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                               project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetConnectorCustomSecretManagerResult]:
    """
    Datasource for looking up a Custom Secret Manager connector.


    :param Sequence[_builtins.str] delegate_selectors: Tags to filter delegates for connection.
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['delegateSelectors'] = delegate_selectors
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getConnectorCustomSecretManager:getConnectorCustomSecretManager', __args__, opts=opts, typ=GetConnectorCustomSecretManagerResult)
    return __ret__.apply(lambda __response__: GetConnectorCustomSecretManagerResult(
        delegate_selectors=pulumi.get(__response__, 'delegate_selectors'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        on_delegate=pulumi.get(__response__, 'on_delegate'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        ssh_secret_ref=pulumi.get(__response__, 'ssh_secret_ref'),
        tags=pulumi.get(__response__, 'tags'),
        target_host=pulumi.get(__response__, 'target_host'),
        template_inputs=pulumi.get(__response__, 'template_inputs'),
        template_ref=pulumi.get(__response__, 'template_ref'),
        timeout=pulumi.get(__response__, 'timeout'),
        type=pulumi.get(__response__, 'type'),
        version_label=pulumi.get(__response__, 'version_label'),
        working_directory=pulumi.get(__response__, 'working_directory')))
