# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IdpEnvironmentArgs', 'IdpEnvironment']

@pulumi.input_type
class IdpEnvironmentArgs:
    def __init__(__self__, *,
                 blueprint_identifier: pulumi.Input[_builtins.str],
                 blueprint_version: pulumi.Input[_builtins.str],
                 identifier: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 overrides: pulumi.Input[_builtins.str],
                 owner: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 based_on: Optional[pulumi.Input[_builtins.str]] = None,
                 inputs: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 target_state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a IdpEnvironment resource.
        :param pulumi.Input[_builtins.str] blueprint_identifier: Blueprint to base the environment on
        :param pulumi.Input[_builtins.str] blueprint_version: Version of the blueprint to base the environment on
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] overrides: Overrides for environment blueprint inputs in YAML format
        :param pulumi.Input[_builtins.str] owner: Owner of the environment
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] based_on: Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        :param pulumi.Input[_builtins.str] inputs: Additional inputs for controlling the environment in YAML format
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] target_state: target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        pulumi.set(__self__, "blueprint_identifier", blueprint_identifier)
        pulumi.set(__self__, "blueprint_version", blueprint_version)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "overrides", overrides)
        pulumi.set(__self__, "owner", owner)
        pulumi.set(__self__, "project_id", project_id)
        if based_on is not None:
            pulumi.set(__self__, "based_on", based_on)
        if inputs is not None:
            pulumi.set(__self__, "inputs", inputs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if target_state is not None:
            pulumi.set(__self__, "target_state", target_state)

    @_builtins.property
    @pulumi.getter(name="blueprintIdentifier")
    def blueprint_identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_identifier")

    @blueprint_identifier.setter
    def blueprint_identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "blueprint_identifier", value)

    @_builtins.property
    @pulumi.getter(name="blueprintVersion")
    def blueprint_version(self) -> pulumi.Input[_builtins.str]:
        """
        Version of the blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_version")

    @blueprint_version.setter
    def blueprint_version(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "blueprint_version", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def overrides(self) -> pulumi.Input[_builtins.str]:
        """
        Overrides for environment blueprint inputs in YAML format
        """
        return pulumi.get(self, "overrides")

    @overrides.setter
    def overrides(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "overrides", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> pulumi.Input[_builtins.str]:
        """
        Owner of the environment
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="basedOn")
    def based_on(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        """
        return pulumi.get(self, "based_on")

    @based_on.setter
    def based_on(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "based_on", value)

    @_builtins.property
    @pulumi.getter
    def inputs(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional inputs for controlling the environment in YAML format
        """
        return pulumi.get(self, "inputs")

    @inputs.setter
    def inputs(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "inputs", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="targetState")
    def target_state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        return pulumi.get(self, "target_state")

    @target_state.setter
    def target_state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_state", value)


@pulumi.input_type
class _IdpEnvironmentState:
    def __init__(__self__, *,
                 based_on: Optional[pulumi.Input[_builtins.str]] = None,
                 blueprint_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 blueprint_version: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 inputs: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 overrides: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 target_state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering IdpEnvironment resources.
        :param pulumi.Input[_builtins.str] based_on: Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        :param pulumi.Input[_builtins.str] blueprint_identifier: Blueprint to base the environment on
        :param pulumi.Input[_builtins.str] blueprint_version: Version of the blueprint to base the environment on
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] inputs: Additional inputs for controlling the environment in YAML format
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] overrides: Overrides for environment blueprint inputs in YAML format
        :param pulumi.Input[_builtins.str] owner: Owner of the environment
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] target_state: target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        if based_on is not None:
            pulumi.set(__self__, "based_on", based_on)
        if blueprint_identifier is not None:
            pulumi.set(__self__, "blueprint_identifier", blueprint_identifier)
        if blueprint_version is not None:
            pulumi.set(__self__, "blueprint_version", blueprint_version)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if inputs is not None:
            pulumi.set(__self__, "inputs", inputs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if overrides is not None:
            pulumi.set(__self__, "overrides", overrides)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if target_state is not None:
            pulumi.set(__self__, "target_state", target_state)

    @_builtins.property
    @pulumi.getter(name="basedOn")
    def based_on(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        """
        return pulumi.get(self, "based_on")

    @based_on.setter
    def based_on(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "based_on", value)

    @_builtins.property
    @pulumi.getter(name="blueprintIdentifier")
    def blueprint_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_identifier")

    @blueprint_identifier.setter
    def blueprint_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "blueprint_identifier", value)

    @_builtins.property
    @pulumi.getter(name="blueprintVersion")
    def blueprint_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Version of the blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_version")

    @blueprint_version.setter
    def blueprint_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "blueprint_version", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def inputs(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional inputs for controlling the environment in YAML format
        """
        return pulumi.get(self, "inputs")

    @inputs.setter
    def inputs(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "inputs", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def overrides(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Overrides for environment blueprint inputs in YAML format
        """
        return pulumi.get(self, "overrides")

    @overrides.setter
    def overrides(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "overrides", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Owner of the environment
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="targetState")
    def target_state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        return pulumi.get(self, "target_state")

    @target_state.setter
    def target_state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_state", value)


@pulumi.type_token("harness:platform/idpEnvironment:IdpEnvironment")
class IdpEnvironment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 based_on: Optional[pulumi.Input[_builtins.str]] = None,
                 blueprint_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 blueprint_version: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 inputs: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 overrides: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 target_state: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating IDP environments.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.platform.IdpEnvironment("test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="test",
            owner="group:account/_account_all_users",
            blueprint_identifier="blueprint_identifier",
            blueprint_version="v1.0.0",
            target_state="running",
            based_on="org_id.project_id/environment_identifier",
            overrides=\"\"\"config: {}
        entities: {}
        \"\"\",
            inputs="ttl: 1h30m\\n")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import environment

        ```sh
        $ pulumi import harness:platform/idpEnvironment:IdpEnvironment example <org_id>/<project_id>/<environment_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] based_on: Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        :param pulumi.Input[_builtins.str] blueprint_identifier: Blueprint to base the environment on
        :param pulumi.Input[_builtins.str] blueprint_version: Version of the blueprint to base the environment on
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] inputs: Additional inputs for controlling the environment in YAML format
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] overrides: Overrides for environment blueprint inputs in YAML format
        :param pulumi.Input[_builtins.str] owner: Owner of the environment
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] target_state: target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IdpEnvironmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating IDP environments.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.platform.IdpEnvironment("test",
            identifier="identifier",
            org_id="org_id",
            project_id="project_id",
            name="test",
            owner="group:account/_account_all_users",
            blueprint_identifier="blueprint_identifier",
            blueprint_version="v1.0.0",
            target_state="running",
            based_on="org_id.project_id/environment_identifier",
            overrides=\"\"\"config: {}
        entities: {}
        \"\"\",
            inputs="ttl: 1h30m\\n")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import environment

        ```sh
        $ pulumi import harness:platform/idpEnvironment:IdpEnvironment example <org_id>/<project_id>/<environment_id>
        ```

        :param str resource_name: The name of the resource.
        :param IdpEnvironmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IdpEnvironmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 based_on: Optional[pulumi.Input[_builtins.str]] = None,
                 blueprint_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 blueprint_version: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 inputs: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 overrides: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 target_state: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IdpEnvironmentArgs.__new__(IdpEnvironmentArgs)

            __props__.__dict__["based_on"] = based_on
            if blueprint_identifier is None and not opts.urn:
                raise TypeError("Missing required property 'blueprint_identifier'")
            __props__.__dict__["blueprint_identifier"] = blueprint_identifier
            if blueprint_version is None and not opts.urn:
                raise TypeError("Missing required property 'blueprint_version'")
            __props__.__dict__["blueprint_version"] = blueprint_version
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["inputs"] = inputs
            __props__.__dict__["name"] = name
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if overrides is None and not opts.urn:
                raise TypeError("Missing required property 'overrides'")
            __props__.__dict__["overrides"] = overrides
            if owner is None and not opts.urn:
                raise TypeError("Missing required property 'owner'")
            __props__.__dict__["owner"] = owner
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["target_state"] = target_state
        super(IdpEnvironment, __self__).__init__(
            'harness:platform/idpEnvironment:IdpEnvironment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            based_on: Optional[pulumi.Input[_builtins.str]] = None,
            blueprint_identifier: Optional[pulumi.Input[_builtins.str]] = None,
            blueprint_version: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            inputs: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            overrides: Optional[pulumi.Input[_builtins.str]] = None,
            owner: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            target_state: Optional[pulumi.Input[_builtins.str]] = None) -> 'IdpEnvironment':
        """
        Get an existing IdpEnvironment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] based_on: Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        :param pulumi.Input[_builtins.str] blueprint_identifier: Blueprint to base the environment on
        :param pulumi.Input[_builtins.str] blueprint_version: Version of the blueprint to base the environment on
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] inputs: Additional inputs for controlling the environment in YAML format
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] overrides: Overrides for environment blueprint inputs in YAML format
        :param pulumi.Input[_builtins.str] owner: Owner of the environment
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] target_state: target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IdpEnvironmentState.__new__(_IdpEnvironmentState)

        __props__.__dict__["based_on"] = based_on
        __props__.__dict__["blueprint_identifier"] = blueprint_identifier
        __props__.__dict__["blueprint_version"] = blueprint_version
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["inputs"] = inputs
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["overrides"] = overrides
        __props__.__dict__["owner"] = owner
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["target_state"] = target_state
        return IdpEnvironment(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="basedOn")
    def based_on(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        """
        return pulumi.get(self, "based_on")

    @_builtins.property
    @pulumi.getter(name="blueprintIdentifier")
    def blueprint_identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_identifier")

    @_builtins.property
    @pulumi.getter(name="blueprintVersion")
    def blueprint_version(self) -> pulumi.Output[_builtins.str]:
        """
        Version of the blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_version")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def inputs(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Additional inputs for controlling the environment in YAML format
        """
        return pulumi.get(self, "inputs")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def overrides(self) -> pulumi.Output[_builtins.str]:
        """
        Overrides for environment blueprint inputs in YAML format
        """
        return pulumi.get(self, "overrides")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> pulumi.Output[_builtins.str]:
        """
        Owner of the environment
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="targetState")
    def target_state(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        return pulumi.get(self, "target_state")

