# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetGitopsAgentDeployYamlResult',
    'AwaitableGetGitopsAgentDeployYamlResult',
    'get_gitops_agent_deploy_yaml',
    'get_gitops_agent_deploy_yaml_output',
]

@pulumi.output_type
class GetGitopsAgentDeployYamlResult:
    """
    A collection of values returned by getGitopsAgentDeployYaml.
    """
    def __init__(__self__, account_id=None, argocd_settings=None, ca_data=None, id=None, identifier=None, namespace=None, org_id=None, private_key=None, project_id=None, proxies=None, skip_crds=None, yaml=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if argocd_settings and not isinstance(argocd_settings, dict):
            raise TypeError("Expected argument 'argocd_settings' to be a dict")
        pulumi.set(__self__, "argocd_settings", argocd_settings)
        if ca_data and not isinstance(ca_data, str):
            raise TypeError("Expected argument 'ca_data' to be a str")
        pulumi.set(__self__, "ca_data", ca_data)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if private_key and not isinstance(private_key, str):
            raise TypeError("Expected argument 'private_key' to be a str")
        pulumi.set(__self__, "private_key", private_key)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if proxies and not isinstance(proxies, list):
            raise TypeError("Expected argument 'proxies' to be a list")
        pulumi.set(__self__, "proxies", proxies)
        if skip_crds and not isinstance(skip_crds, bool):
            raise TypeError("Expected argument 'skip_crds' to be a bool")
        pulumi.set(__self__, "skip_crds", skip_crds)
        if yaml and not isinstance(yaml, str):
            raise TypeError("Expected argument 'yaml' to be a str")
        pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> _builtins.str:
        """
        Account identifier of the GitOps agent.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="argocdSettings")
    def argocd_settings(self) -> Optional['outputs.GetGitopsAgentDeployYamlArgocdSettingsResult']:
        """
        Argocd settings for the GitOps agent. Values set here will be overridden by the values set in the argocd settings in case of complete installation of agent + argocd. Each param contains as a description about what it will enable.
        """
        return pulumi.get(self, "argocd_settings")

    @_builtins.property
    @pulumi.getter(name="caData")
    def ca_data(self) -> Optional[_builtins.str]:
        """
        CA data of the GitOps agent, base64 encoded content of ca chain.
        """
        return pulumi.get(self, "ca_data")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the GitOps agent.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> _builtins.str:
        """
        The kubernetes namespace where the agent is installed.
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Organization identifier of the GitOps agent.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[_builtins.str]:
        """
        Private key for the GitOps agent. If provided authentication token will not be regenerated. Must be base64 encoded.
        """
        return pulumi.get(self, "private_key")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Project identifier of the GitOps agent.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def proxies(self) -> Optional[Sequence['outputs.GetGitopsAgentDeployYamlProxyResult']]:
        """
        Proxy settings for the GitOps agent.
        """
        return pulumi.get(self, "proxies")

    @_builtins.property
    @pulumi.getter(name="skipCrds")
    def skip_crds(self) -> Optional[_builtins.bool]:
        """
        Skip CRDs for the GitOps agent.
        """
        return pulumi.get(self, "skip_crds")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> _builtins.str:
        """
        The deployment manifest YAML of the GitOps agent.
        """
        return pulumi.get(self, "yaml")


class AwaitableGetGitopsAgentDeployYamlResult(GetGitopsAgentDeployYamlResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGitopsAgentDeployYamlResult(
            account_id=self.account_id,
            argocd_settings=self.argocd_settings,
            ca_data=self.ca_data,
            id=self.id,
            identifier=self.identifier,
            namespace=self.namespace,
            org_id=self.org_id,
            private_key=self.private_key,
            project_id=self.project_id,
            proxies=self.proxies,
            skip_crds=self.skip_crds,
            yaml=self.yaml)


def get_gitops_agent_deploy_yaml(account_id: Optional[_builtins.str] = None,
                                 argocd_settings: Optional[Union['GetGitopsAgentDeployYamlArgocdSettingsArgs', 'GetGitopsAgentDeployYamlArgocdSettingsArgsDict']] = None,
                                 ca_data: Optional[_builtins.str] = None,
                                 identifier: Optional[_builtins.str] = None,
                                 namespace: Optional[_builtins.str] = None,
                                 org_id: Optional[_builtins.str] = None,
                                 private_key: Optional[_builtins.str] = None,
                                 project_id: Optional[_builtins.str] = None,
                                 proxies: Optional[Sequence[Union['GetGitopsAgentDeployYamlProxyArgs', 'GetGitopsAgentDeployYamlProxyArgsDict']]] = None,
                                 skip_crds: Optional[_builtins.bool] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGitopsAgentDeployYamlResult:
    """
    Datasource for fetching a Harness Gitops Agent deployment manifest YAML.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_gitops_agent_deploy_yaml(identifier="identifier",
        account_id="account_id",
        project_id="project_id",
        org_id="org_id",
        namespace="namespace")
    ```


    :param _builtins.str account_id: Account identifier of the GitOps agent.
    :param Union['GetGitopsAgentDeployYamlArgocdSettingsArgs', 'GetGitopsAgentDeployYamlArgocdSettingsArgsDict'] argocd_settings: Argocd settings for the GitOps agent. Values set here will be overridden by the values set in the argocd settings in case of complete installation of agent + argocd. Each param contains as a description about what it will enable.
    :param _builtins.str ca_data: CA data of the GitOps agent, base64 encoded content of ca chain.
    :param _builtins.str identifier: Identifier of the GitOps agent.
    :param _builtins.str namespace: The kubernetes namespace where the agent is installed.
    :param _builtins.str org_id: Organization identifier of the GitOps agent.
    :param _builtins.str private_key: Private key for the GitOps agent. If provided authentication token will not be regenerated. Must be base64 encoded.
    :param _builtins.str project_id: Project identifier of the GitOps agent.
    :param Sequence[Union['GetGitopsAgentDeployYamlProxyArgs', 'GetGitopsAgentDeployYamlProxyArgsDict']] proxies: Proxy settings for the GitOps agent.
    :param _builtins.bool skip_crds: Skip CRDs for the GitOps agent.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['argocdSettings'] = argocd_settings
    __args__['caData'] = ca_data
    __args__['identifier'] = identifier
    __args__['namespace'] = namespace
    __args__['orgId'] = org_id
    __args__['privateKey'] = private_key
    __args__['projectId'] = project_id
    __args__['proxies'] = proxies
    __args__['skipCrds'] = skip_crds
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getGitopsAgentDeployYaml:getGitopsAgentDeployYaml', __args__, opts=opts, typ=GetGitopsAgentDeployYamlResult).value

    return AwaitableGetGitopsAgentDeployYamlResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        argocd_settings=pulumi.get(__ret__, 'argocd_settings'),
        ca_data=pulumi.get(__ret__, 'ca_data'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        namespace=pulumi.get(__ret__, 'namespace'),
        org_id=pulumi.get(__ret__, 'org_id'),
        private_key=pulumi.get(__ret__, 'private_key'),
        project_id=pulumi.get(__ret__, 'project_id'),
        proxies=pulumi.get(__ret__, 'proxies'),
        skip_crds=pulumi.get(__ret__, 'skip_crds'),
        yaml=pulumi.get(__ret__, 'yaml'))
def get_gitops_agent_deploy_yaml_output(account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        argocd_settings: Optional[pulumi.Input[Optional[Union['GetGitopsAgentDeployYamlArgocdSettingsArgs', 'GetGitopsAgentDeployYamlArgocdSettingsArgsDict']]]] = None,
                                        ca_data: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                        namespace: Optional[pulumi.Input[_builtins.str]] = None,
                                        org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        private_key: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        proxies: Optional[pulumi.Input[Optional[Sequence[Union['GetGitopsAgentDeployYamlProxyArgs', 'GetGitopsAgentDeployYamlProxyArgsDict']]]]] = None,
                                        skip_crds: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGitopsAgentDeployYamlResult]:
    """
    Datasource for fetching a Harness Gitops Agent deployment manifest YAML.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_gitops_agent_deploy_yaml(identifier="identifier",
        account_id="account_id",
        project_id="project_id",
        org_id="org_id",
        namespace="namespace")
    ```


    :param _builtins.str account_id: Account identifier of the GitOps agent.
    :param Union['GetGitopsAgentDeployYamlArgocdSettingsArgs', 'GetGitopsAgentDeployYamlArgocdSettingsArgsDict'] argocd_settings: Argocd settings for the GitOps agent. Values set here will be overridden by the values set in the argocd settings in case of complete installation of agent + argocd. Each param contains as a description about what it will enable.
    :param _builtins.str ca_data: CA data of the GitOps agent, base64 encoded content of ca chain.
    :param _builtins.str identifier: Identifier of the GitOps agent.
    :param _builtins.str namespace: The kubernetes namespace where the agent is installed.
    :param _builtins.str org_id: Organization identifier of the GitOps agent.
    :param _builtins.str private_key: Private key for the GitOps agent. If provided authentication token will not be regenerated. Must be base64 encoded.
    :param _builtins.str project_id: Project identifier of the GitOps agent.
    :param Sequence[Union['GetGitopsAgentDeployYamlProxyArgs', 'GetGitopsAgentDeployYamlProxyArgsDict']] proxies: Proxy settings for the GitOps agent.
    :param _builtins.bool skip_crds: Skip CRDs for the GitOps agent.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['argocdSettings'] = argocd_settings
    __args__['caData'] = ca_data
    __args__['identifier'] = identifier
    __args__['namespace'] = namespace
    __args__['orgId'] = org_id
    __args__['privateKey'] = private_key
    __args__['projectId'] = project_id
    __args__['proxies'] = proxies
    __args__['skipCrds'] = skip_crds
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getGitopsAgentDeployYaml:getGitopsAgentDeployYaml', __args__, opts=opts, typ=GetGitopsAgentDeployYamlResult)
    return __ret__.apply(lambda __response__: GetGitopsAgentDeployYamlResult(
        account_id=pulumi.get(__response__, 'account_id'),
        argocd_settings=pulumi.get(__response__, 'argocd_settings'),
        ca_data=pulumi.get(__response__, 'ca_data'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        namespace=pulumi.get(__response__, 'namespace'),
        org_id=pulumi.get(__response__, 'org_id'),
        private_key=pulumi.get(__response__, 'private_key'),
        project_id=pulumi.get(__response__, 'project_id'),
        proxies=pulumi.get(__response__, 'proxies'),
        skip_crds=pulumi.get(__response__, 'skip_crds'),
        yaml=pulumi.get(__response__, 'yaml')))
