# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KubernetesConnectorArgs', 'KubernetesConnector']

@pulumi.input_type
class KubernetesConnectorArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 client_key_cert: Optional[pulumi.Input['KubernetesConnectorClientKeyCertArgs']] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 inherit_from_delegate: Optional[pulumi.Input['KubernetesConnectorInheritFromDelegateArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 openid_connect: Optional[pulumi.Input['KubernetesConnectorOpenidConnectArgs']] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_account: Optional[pulumi.Input['KubernetesConnectorServiceAccountArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 username_password: Optional[pulumi.Input['KubernetesConnectorUsernamePasswordArgs']] = None):
        """
        The set of arguments for constructing a KubernetesConnector resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input['KubernetesConnectorClientKeyCertArgs'] client_key_cert: Client key and certificate config for the connector.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Selectors to use for the delegate.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of connector
        :param pulumi.Input['KubernetesConnectorInheritFromDelegateArgs'] inherit_from_delegate: Credentials are inherited from the delegate.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input['KubernetesConnectorOpenidConnectArgs'] openid_connect: OpenID configuration for the connector.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input['KubernetesConnectorServiceAccountArgs'] service_account: Service account for the connector.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input['KubernetesConnectorUsernamePasswordArgs'] username_password: Username and password for the connector.
        """
        pulumi.set(__self__, "identifier", identifier)
        if client_key_cert is not None:
            pulumi.set(__self__, "client_key_cert", client_key_cert)
        if delegate_selectors is not None:
            pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if inherit_from_delegate is not None:
            pulumi.set(__self__, "inherit_from_delegate", inherit_from_delegate)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if openid_connect is not None:
            pulumi.set(__self__, "openid_connect", openid_connect)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if service_account is not None:
            pulumi.set(__self__, "service_account", service_account)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if username_password is not None:
            pulumi.set(__self__, "username_password", username_password)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="clientKeyCert")
    def client_key_cert(self) -> Optional[pulumi.Input['KubernetesConnectorClientKeyCertArgs']]:
        """
        Client key and certificate config for the connector.
        """
        return pulumi.get(self, "client_key_cert")

    @client_key_cert.setter
    def client_key_cert(self, value: Optional[pulumi.Input['KubernetesConnectorClientKeyCertArgs']]):
        pulumi.set(self, "client_key_cert", value)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Selectors to use for the delegate.
        """
        return pulumi.get(self, "delegate_selectors")

    @delegate_selectors.setter
    def delegate_selectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "delegate_selectors", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable this flag for force deletion of connector
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @_builtins.property
    @pulumi.getter(name="inheritFromDelegate")
    def inherit_from_delegate(self) -> Optional[pulumi.Input['KubernetesConnectorInheritFromDelegateArgs']]:
        """
        Credentials are inherited from the delegate.
        """
        return pulumi.get(self, "inherit_from_delegate")

    @inherit_from_delegate.setter
    def inherit_from_delegate(self, value: Optional[pulumi.Input['KubernetesConnectorInheritFromDelegateArgs']]):
        pulumi.set(self, "inherit_from_delegate", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="openidConnect")
    def openid_connect(self) -> Optional[pulumi.Input['KubernetesConnectorOpenidConnectArgs']]:
        """
        OpenID configuration for the connector.
        """
        return pulumi.get(self, "openid_connect")

    @openid_connect.setter
    def openid_connect(self, value: Optional[pulumi.Input['KubernetesConnectorOpenidConnectArgs']]):
        pulumi.set(self, "openid_connect", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="serviceAccount")
    def service_account(self) -> Optional[pulumi.Input['KubernetesConnectorServiceAccountArgs']]:
        """
        Service account for the connector.
        """
        return pulumi.get(self, "service_account")

    @service_account.setter
    def service_account(self, value: Optional[pulumi.Input['KubernetesConnectorServiceAccountArgs']]):
        pulumi.set(self, "service_account", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="usernamePassword")
    def username_password(self) -> Optional[pulumi.Input['KubernetesConnectorUsernamePasswordArgs']]:
        """
        Username and password for the connector.
        """
        return pulumi.get(self, "username_password")

    @username_password.setter
    def username_password(self, value: Optional[pulumi.Input['KubernetesConnectorUsernamePasswordArgs']]):
        pulumi.set(self, "username_password", value)


@pulumi.input_type
class _KubernetesConnectorState:
    def __init__(__self__, *,
                 client_key_cert: Optional[pulumi.Input['KubernetesConnectorClientKeyCertArgs']] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 inherit_from_delegate: Optional[pulumi.Input['KubernetesConnectorInheritFromDelegateArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 openid_connect: Optional[pulumi.Input['KubernetesConnectorOpenidConnectArgs']] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_account: Optional[pulumi.Input['KubernetesConnectorServiceAccountArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 username_password: Optional[pulumi.Input['KubernetesConnectorUsernamePasswordArgs']] = None):
        """
        Input properties used for looking up and filtering KubernetesConnector resources.
        :param pulumi.Input['KubernetesConnectorClientKeyCertArgs'] client_key_cert: Client key and certificate config for the connector.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Selectors to use for the delegate.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of connector
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input['KubernetesConnectorInheritFromDelegateArgs'] inherit_from_delegate: Credentials are inherited from the delegate.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input['KubernetesConnectorOpenidConnectArgs'] openid_connect: OpenID configuration for the connector.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input['KubernetesConnectorServiceAccountArgs'] service_account: Service account for the connector.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input['KubernetesConnectorUsernamePasswordArgs'] username_password: Username and password for the connector.
        """
        if client_key_cert is not None:
            pulumi.set(__self__, "client_key_cert", client_key_cert)
        if delegate_selectors is not None:
            pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if inherit_from_delegate is not None:
            pulumi.set(__self__, "inherit_from_delegate", inherit_from_delegate)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if openid_connect is not None:
            pulumi.set(__self__, "openid_connect", openid_connect)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if service_account is not None:
            pulumi.set(__self__, "service_account", service_account)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if username_password is not None:
            pulumi.set(__self__, "username_password", username_password)

    @_builtins.property
    @pulumi.getter(name="clientKeyCert")
    def client_key_cert(self) -> Optional[pulumi.Input['KubernetesConnectorClientKeyCertArgs']]:
        """
        Client key and certificate config for the connector.
        """
        return pulumi.get(self, "client_key_cert")

    @client_key_cert.setter
    def client_key_cert(self, value: Optional[pulumi.Input['KubernetesConnectorClientKeyCertArgs']]):
        pulumi.set(self, "client_key_cert", value)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Selectors to use for the delegate.
        """
        return pulumi.get(self, "delegate_selectors")

    @delegate_selectors.setter
    def delegate_selectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "delegate_selectors", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable this flag for force deletion of connector
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="inheritFromDelegate")
    def inherit_from_delegate(self) -> Optional[pulumi.Input['KubernetesConnectorInheritFromDelegateArgs']]:
        """
        Credentials are inherited from the delegate.
        """
        return pulumi.get(self, "inherit_from_delegate")

    @inherit_from_delegate.setter
    def inherit_from_delegate(self, value: Optional[pulumi.Input['KubernetesConnectorInheritFromDelegateArgs']]):
        pulumi.set(self, "inherit_from_delegate", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="openidConnect")
    def openid_connect(self) -> Optional[pulumi.Input['KubernetesConnectorOpenidConnectArgs']]:
        """
        OpenID configuration for the connector.
        """
        return pulumi.get(self, "openid_connect")

    @openid_connect.setter
    def openid_connect(self, value: Optional[pulumi.Input['KubernetesConnectorOpenidConnectArgs']]):
        pulumi.set(self, "openid_connect", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="serviceAccount")
    def service_account(self) -> Optional[pulumi.Input['KubernetesConnectorServiceAccountArgs']]:
        """
        Service account for the connector.
        """
        return pulumi.get(self, "service_account")

    @service_account.setter
    def service_account(self, value: Optional[pulumi.Input['KubernetesConnectorServiceAccountArgs']]):
        pulumi.set(self, "service_account", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="usernamePassword")
    def username_password(self) -> Optional[pulumi.Input['KubernetesConnectorUsernamePasswordArgs']]:
        """
        Username and password for the connector.
        """
        return pulumi.get(self, "username_password")

    @username_password.setter
    def username_password(self, value: Optional[pulumi.Input['KubernetesConnectorUsernamePasswordArgs']]):
        pulumi.set(self, "username_password", value)


@pulumi.type_token("harness:platform/kubernetesConnector:KubernetesConnector")
class KubernetesConnector(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_key_cert: Optional[pulumi.Input[Union['KubernetesConnectorClientKeyCertArgs', 'KubernetesConnectorClientKeyCertArgsDict']]] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 inherit_from_delegate: Optional[pulumi.Input[Union['KubernetesConnectorInheritFromDelegateArgs', 'KubernetesConnectorInheritFromDelegateArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 openid_connect: Optional[pulumi.Input[Union['KubernetesConnectorOpenidConnectArgs', 'KubernetesConnectorOpenidConnectArgsDict']]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_account: Optional[pulumi.Input[Union['KubernetesConnectorServiceAccountArgs', 'KubernetesConnectorServiceAccountArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 username_password: Optional[pulumi.Input[Union['KubernetesConnectorUsernamePasswordArgs', 'KubernetesConnectorUsernamePasswordArgsDict']]] = None,
                 __props__=None):
        """
        Resource for creating a K8s connector.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        client_key_cert = harness.platform.KubernetesConnector("clientKeyCert",
            identifier="identifier",
            name="name",
            description="description",
            tags=["foo:bar"],
            client_key_cert={
                "master_url": "https://kubernetes.example.com",
                "ca_cert_ref": "account.TEST_k8ss_client_stuff",
                "client_cert_ref": "account.test_k8s_client_cert",
                "client_key_ref": "account.TEST_k8s_client_key",
                "client_key_passphrase_ref": "account.TEST_k8s_client_test",
                "client_key_algorithm": "RSA",
            },
            delegate_selectors=["harness-delegate"])
        username_password = harness.platform.KubernetesConnector("usernamePassword",
            identifier="identifier",
            name="name",
            description="description",
            tags=["foo:bar"],
            username_password={
                "master_url": "https://kubernetes.example.com",
                "username": "admin",
                "password_ref": "account.TEST_k8s_client_test",
            },
            delegate_selectors=["harness-delegate"])
        service_account = harness.platform.KubernetesConnector("serviceAccount",
            identifier="identifier",
            name="name",
            description="description",
            tags=["foo:bar"],
            service_account={
                "master_url": "https://kubernetes.example.com",
                "service_account_token_ref": "account.TEST_k8s_client_test",
            },
            delegate_selectors=["harness-delegate"])
        open_id_connect = harness.platform.KubernetesConnector("openIDConnect",
            identifier="%[1]s",
            name="%[2]s",
            description="description",
            tags=["foo:bar"],
            openid_connect={
                "master_url": "https://kubernetes.example.com",
                "issuer_url": "https://oidc.example.com",
                "username_ref": "account.TEST_k8s_client_test",
                "client_id_ref": "account.TEST_k8s_client_test",
                "password_ref": "account.TEST_k8s_client_test",
                "secret_ref": "account.TEST_k8s_client_test",
                "scopes": [
                    "scope1",
                    "scope2",
                ],
            },
            delegate_selectors=["harness-delegate"])
        inherit_from_delegate = harness.platform.KubernetesConnector("inheritFromDelegate",
            identifier="identifier",
            name="name",
            description="description",
            tags=["foo:bar"],
            inherit_from_delegate={
                "delegate_selectors": ["harness-delegate"],
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level kubernetes connector

        ```sh
        $ pulumi import harness:platform/kubernetesConnector:KubernetesConnector example <connector_id>
        ```

        Import org level kubernetes connector

        ```sh
        $ pulumi import harness:platform/kubernetesConnector:KubernetesConnector example <ord_id>/<connector_id>
        ```

        Import project level kubernetes connector

        ```sh
        $ pulumi import harness:platform/kubernetesConnector:KubernetesConnector example <org_id>/<project_id>/<connector_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['KubernetesConnectorClientKeyCertArgs', 'KubernetesConnectorClientKeyCertArgsDict']] client_key_cert: Client key and certificate config for the connector.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Selectors to use for the delegate.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of connector
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Union['KubernetesConnectorInheritFromDelegateArgs', 'KubernetesConnectorInheritFromDelegateArgsDict']] inherit_from_delegate: Credentials are inherited from the delegate.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Union['KubernetesConnectorOpenidConnectArgs', 'KubernetesConnectorOpenidConnectArgsDict']] openid_connect: OpenID configuration for the connector.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Union['KubernetesConnectorServiceAccountArgs', 'KubernetesConnectorServiceAccountArgsDict']] service_account: Service account for the connector.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Union['KubernetesConnectorUsernamePasswordArgs', 'KubernetesConnectorUsernamePasswordArgsDict']] username_password: Username and password for the connector.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KubernetesConnectorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a K8s connector.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        client_key_cert = harness.platform.KubernetesConnector("clientKeyCert",
            identifier="identifier",
            name="name",
            description="description",
            tags=["foo:bar"],
            client_key_cert={
                "master_url": "https://kubernetes.example.com",
                "ca_cert_ref": "account.TEST_k8ss_client_stuff",
                "client_cert_ref": "account.test_k8s_client_cert",
                "client_key_ref": "account.TEST_k8s_client_key",
                "client_key_passphrase_ref": "account.TEST_k8s_client_test",
                "client_key_algorithm": "RSA",
            },
            delegate_selectors=["harness-delegate"])
        username_password = harness.platform.KubernetesConnector("usernamePassword",
            identifier="identifier",
            name="name",
            description="description",
            tags=["foo:bar"],
            username_password={
                "master_url": "https://kubernetes.example.com",
                "username": "admin",
                "password_ref": "account.TEST_k8s_client_test",
            },
            delegate_selectors=["harness-delegate"])
        service_account = harness.platform.KubernetesConnector("serviceAccount",
            identifier="identifier",
            name="name",
            description="description",
            tags=["foo:bar"],
            service_account={
                "master_url": "https://kubernetes.example.com",
                "service_account_token_ref": "account.TEST_k8s_client_test",
            },
            delegate_selectors=["harness-delegate"])
        open_id_connect = harness.platform.KubernetesConnector("openIDConnect",
            identifier="%[1]s",
            name="%[2]s",
            description="description",
            tags=["foo:bar"],
            openid_connect={
                "master_url": "https://kubernetes.example.com",
                "issuer_url": "https://oidc.example.com",
                "username_ref": "account.TEST_k8s_client_test",
                "client_id_ref": "account.TEST_k8s_client_test",
                "password_ref": "account.TEST_k8s_client_test",
                "secret_ref": "account.TEST_k8s_client_test",
                "scopes": [
                    "scope1",
                    "scope2",
                ],
            },
            delegate_selectors=["harness-delegate"])
        inherit_from_delegate = harness.platform.KubernetesConnector("inheritFromDelegate",
            identifier="identifier",
            name="name",
            description="description",
            tags=["foo:bar"],
            inherit_from_delegate={
                "delegate_selectors": ["harness-delegate"],
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level kubernetes connector

        ```sh
        $ pulumi import harness:platform/kubernetesConnector:KubernetesConnector example <connector_id>
        ```

        Import org level kubernetes connector

        ```sh
        $ pulumi import harness:platform/kubernetesConnector:KubernetesConnector example <ord_id>/<connector_id>
        ```

        Import project level kubernetes connector

        ```sh
        $ pulumi import harness:platform/kubernetesConnector:KubernetesConnector example <org_id>/<project_id>/<connector_id>
        ```

        :param str resource_name: The name of the resource.
        :param KubernetesConnectorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KubernetesConnectorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_key_cert: Optional[pulumi.Input[Union['KubernetesConnectorClientKeyCertArgs', 'KubernetesConnectorClientKeyCertArgsDict']]] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 inherit_from_delegate: Optional[pulumi.Input[Union['KubernetesConnectorInheritFromDelegateArgs', 'KubernetesConnectorInheritFromDelegateArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 openid_connect: Optional[pulumi.Input[Union['KubernetesConnectorOpenidConnectArgs', 'KubernetesConnectorOpenidConnectArgsDict']]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_account: Optional[pulumi.Input[Union['KubernetesConnectorServiceAccountArgs', 'KubernetesConnectorServiceAccountArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 username_password: Optional[pulumi.Input[Union['KubernetesConnectorUsernamePasswordArgs', 'KubernetesConnectorUsernamePasswordArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KubernetesConnectorArgs.__new__(KubernetesConnectorArgs)

            __props__.__dict__["client_key_cert"] = client_key_cert
            __props__.__dict__["delegate_selectors"] = delegate_selectors
            __props__.__dict__["description"] = description
            __props__.__dict__["force_delete"] = force_delete
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["inherit_from_delegate"] = inherit_from_delegate
            __props__.__dict__["name"] = name
            __props__.__dict__["openid_connect"] = openid_connect
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["service_account"] = service_account
            __props__.__dict__["tags"] = tags
            __props__.__dict__["username_password"] = username_password
        super(KubernetesConnector, __self__).__init__(
            'harness:platform/kubernetesConnector:KubernetesConnector',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            client_key_cert: Optional[pulumi.Input[Union['KubernetesConnectorClientKeyCertArgs', 'KubernetesConnectorClientKeyCertArgsDict']]] = None,
            delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            inherit_from_delegate: Optional[pulumi.Input[Union['KubernetesConnectorInheritFromDelegateArgs', 'KubernetesConnectorInheritFromDelegateArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            openid_connect: Optional[pulumi.Input[Union['KubernetesConnectorOpenidConnectArgs', 'KubernetesConnectorOpenidConnectArgsDict']]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            service_account: Optional[pulumi.Input[Union['KubernetesConnectorServiceAccountArgs', 'KubernetesConnectorServiceAccountArgsDict']]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            username_password: Optional[pulumi.Input[Union['KubernetesConnectorUsernamePasswordArgs', 'KubernetesConnectorUsernamePasswordArgsDict']]] = None) -> 'KubernetesConnector':
        """
        Get an existing KubernetesConnector resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['KubernetesConnectorClientKeyCertArgs', 'KubernetesConnectorClientKeyCertArgsDict']] client_key_cert: Client key and certificate config for the connector.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Selectors to use for the delegate.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of connector
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Union['KubernetesConnectorInheritFromDelegateArgs', 'KubernetesConnectorInheritFromDelegateArgsDict']] inherit_from_delegate: Credentials are inherited from the delegate.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Union['KubernetesConnectorOpenidConnectArgs', 'KubernetesConnectorOpenidConnectArgsDict']] openid_connect: OpenID configuration for the connector.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Union['KubernetesConnectorServiceAccountArgs', 'KubernetesConnectorServiceAccountArgsDict']] service_account: Service account for the connector.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Union['KubernetesConnectorUsernamePasswordArgs', 'KubernetesConnectorUsernamePasswordArgsDict']] username_password: Username and password for the connector.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KubernetesConnectorState.__new__(_KubernetesConnectorState)

        __props__.__dict__["client_key_cert"] = client_key_cert
        __props__.__dict__["delegate_selectors"] = delegate_selectors
        __props__.__dict__["description"] = description
        __props__.__dict__["force_delete"] = force_delete
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["inherit_from_delegate"] = inherit_from_delegate
        __props__.__dict__["name"] = name
        __props__.__dict__["openid_connect"] = openid_connect
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["service_account"] = service_account
        __props__.__dict__["tags"] = tags
        __props__.__dict__["username_password"] = username_password
        return KubernetesConnector(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clientKeyCert")
    def client_key_cert(self) -> pulumi.Output[Optional['outputs.KubernetesConnectorClientKeyCert']]:
        """
        Client key and certificate config for the connector.
        """
        return pulumi.get(self, "client_key_cert")

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Selectors to use for the delegate.
        """
        return pulumi.get(self, "delegate_selectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable this flag for force deletion of connector
        """
        return pulumi.get(self, "force_delete")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="inheritFromDelegate")
    def inherit_from_delegate(self) -> pulumi.Output[Optional['outputs.KubernetesConnectorInheritFromDelegate']]:
        """
        Credentials are inherited from the delegate.
        """
        return pulumi.get(self, "inherit_from_delegate")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="openidConnect")
    def openid_connect(self) -> pulumi.Output[Optional['outputs.KubernetesConnectorOpenidConnect']]:
        """
        OpenID configuration for the connector.
        """
        return pulumi.get(self, "openid_connect")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="serviceAccount")
    def service_account(self) -> pulumi.Output[Optional['outputs.KubernetesConnectorServiceAccount']]:
        """
        Service account for the connector.
        """
        return pulumi.get(self, "service_account")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="usernamePassword")
    def username_password(self) -> pulumi.Output[Optional['outputs.KubernetesConnectorUsernamePassword']]:
        """
        Username and password for the connector.
        """
        return pulumi.get(self, "username_password")

