# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetIdpEnvironmentBlueprintResult',
    'AwaitableGetIdpEnvironmentBlueprintResult',
    'get_idp_environment_blueprint',
    'get_idp_environment_blueprint_output',
]

@pulumi.output_type
class GetIdpEnvironmentBlueprintResult:
    """
    A collection of values returned by getIdpEnvironmentBlueprint.
    """
    def __init__(__self__, deprecated=None, description=None, id=None, identifier=None, stable=None, version=None, yaml=None):
        if deprecated and not isinstance(deprecated, bool):
            raise TypeError("Expected argument 'deprecated' to be a bool")
        pulumi.set(__self__, "deprecated", deprecated)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if stable and not isinstance(stable, bool):
            raise TypeError("Expected argument 'stable' to be a bool")
        pulumi.set(__self__, "stable", stable)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)
        if yaml and not isinstance(yaml, str):
            raise TypeError("Expected argument 'yaml' to be a str")
        pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter
    def deprecated(self) -> _builtins.bool:
        """
        Whether the catalog entity is deprecated
        """
        return pulumi.get(self, "deprecated")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the catalog entity
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def stable(self) -> _builtins.bool:
        """
        Whether the catalog entity is stable
        """
        return pulumi.get(self, "stable")

    @_builtins.property
    @pulumi.getter
    def version(self) -> _builtins.str:
        """
        Version of the environment blueprint
        """
        return pulumi.get(self, "version")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> _builtins.str:
        """
        YAML definition of the catalog entity
        """
        return pulumi.get(self, "yaml")


class AwaitableGetIdpEnvironmentBlueprintResult(GetIdpEnvironmentBlueprintResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIdpEnvironmentBlueprintResult(
            deprecated=self.deprecated,
            description=self.description,
            id=self.id,
            identifier=self.identifier,
            stable=self.stable,
            version=self.version,
            yaml=self.yaml)


def get_idp_environment_blueprint(identifier: Optional[_builtins.str] = None,
                                  version: Optional[_builtins.str] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIdpEnvironmentBlueprintResult:
    """
    Data source for retrieving Harness environment blueprints.


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str version: Version of the environment blueprint
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['version'] = version
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getIdpEnvironmentBlueprint:getIdpEnvironmentBlueprint', __args__, opts=opts, typ=GetIdpEnvironmentBlueprintResult).value

    return AwaitableGetIdpEnvironmentBlueprintResult(
        deprecated=pulumi.get(__ret__, 'deprecated'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        stable=pulumi.get(__ret__, 'stable'),
        version=pulumi.get(__ret__, 'version'),
        yaml=pulumi.get(__ret__, 'yaml'))
def get_idp_environment_blueprint_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                         version: Optional[pulumi.Input[_builtins.str]] = None,
                                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIdpEnvironmentBlueprintResult]:
    """
    Data source for retrieving Harness environment blueprints.


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str version: Version of the environment blueprint
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['version'] = version
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getIdpEnvironmentBlueprint:getIdpEnvironmentBlueprint', __args__, opts=opts, typ=GetIdpEnvironmentBlueprintResult)
    return __ret__.apply(lambda __response__: GetIdpEnvironmentBlueprintResult(
        deprecated=pulumi.get(__response__, 'deprecated'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        stable=pulumi.get(__response__, 'stable'),
        version=pulumi.get(__response__, 'version'),
        yaml=pulumi.get(__response__, 'yaml')))
