# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UsergroupArgs', 'Usergroup']

@pulumi.input_type
class UsergroupArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 externally_managed: Optional[pulumi.Input[_builtins.bool]] = None,
                 linked_sso_display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_id: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_configs: Optional[pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_linked: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_emails: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a Usergroup resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] externally_managed: Whether the user group is externally managed.
        :param pulumi.Input[_builtins.str] linked_sso_display_name: Name of the linked SSO.
        :param pulumi.Input[_builtins.str] linked_sso_id: The SSO account ID that the user group is linked to.
        :param pulumi.Input[_builtins.str] linked_sso_type: Type of linked SSO.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]] notification_configs: List of notification settings.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] sso_group_id: Identifier of the userGroup in SSO.
        :param pulumi.Input[_builtins.str] sso_group_name: Name of the SSO userGroup.
        :param pulumi.Input[_builtins.bool] sso_linked: Whether sso is linked or not.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_emails: List of user emails in the UserGroup. Either provide list of users or list of user emails.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users: List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        pulumi.set(__self__, "identifier", identifier)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if externally_managed is not None:
            pulumi.set(__self__, "externally_managed", externally_managed)
        if linked_sso_display_name is not None:
            pulumi.set(__self__, "linked_sso_display_name", linked_sso_display_name)
        if linked_sso_id is not None:
            pulumi.set(__self__, "linked_sso_id", linked_sso_id)
        if linked_sso_type is not None:
            pulumi.set(__self__, "linked_sso_type", linked_sso_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notification_configs is not None:
            pulumi.set(__self__, "notification_configs", notification_configs)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if sso_group_id is not None:
            pulumi.set(__self__, "sso_group_id", sso_group_id)
        if sso_group_name is not None:
            pulumi.set(__self__, "sso_group_name", sso_group_name)
        if sso_linked is not None:
            pulumi.set(__self__, "sso_linked", sso_linked)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if user_emails is not None:
            pulumi.set(__self__, "user_emails", user_emails)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="externallyManaged")
    def externally_managed(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the user group is externally managed.
        """
        return pulumi.get(self, "externally_managed")

    @externally_managed.setter
    def externally_managed(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "externally_managed", value)

    @_builtins.property
    @pulumi.getter(name="linkedSsoDisplayName")
    def linked_sso_display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the linked SSO.
        """
        return pulumi.get(self, "linked_sso_display_name")

    @linked_sso_display_name.setter
    def linked_sso_display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_sso_display_name", value)

    @_builtins.property
    @pulumi.getter(name="linkedSsoId")
    def linked_sso_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The SSO account ID that the user group is linked to.
        """
        return pulumi.get(self, "linked_sso_id")

    @linked_sso_id.setter
    def linked_sso_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_sso_id", value)

    @_builtins.property
    @pulumi.getter(name="linkedSsoType")
    def linked_sso_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of linked SSO.
        """
        return pulumi.get(self, "linked_sso_type")

    @linked_sso_type.setter
    def linked_sso_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_sso_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notificationConfigs")
    def notification_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]]]:
        """
        List of notification settings.
        """
        return pulumi.get(self, "notification_configs")

    @notification_configs.setter
    def notification_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]]]):
        pulumi.set(self, "notification_configs", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="ssoGroupId")
    def sso_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the userGroup in SSO.
        """
        return pulumi.get(self, "sso_group_id")

    @sso_group_id.setter
    def sso_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sso_group_id", value)

    @_builtins.property
    @pulumi.getter(name="ssoGroupName")
    def sso_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the SSO userGroup.
        """
        return pulumi.get(self, "sso_group_name")

    @sso_group_name.setter
    def sso_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sso_group_name", value)

    @_builtins.property
    @pulumi.getter(name="ssoLinked")
    def sso_linked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether sso is linked or not.
        """
        return pulumi.get(self, "sso_linked")

    @sso_linked.setter
    def sso_linked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sso_linked", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="userEmails")
    def user_emails(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of user emails in the UserGroup. Either provide list of users or list of user emails.
        """
        return pulumi.get(self, "user_emails")

    @user_emails.setter
    def user_emails(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_emails", value)

    @_builtins.property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "users", value)


@pulumi.input_type
class _UsergroupState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 externally_managed: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_id: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_configs: Optional[pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_linked: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_emails: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Usergroup resources.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] externally_managed: Whether the user group is externally managed.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] linked_sso_display_name: Name of the linked SSO.
        :param pulumi.Input[_builtins.str] linked_sso_id: The SSO account ID that the user group is linked to.
        :param pulumi.Input[_builtins.str] linked_sso_type: Type of linked SSO.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]] notification_configs: List of notification settings.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] sso_group_id: Identifier of the userGroup in SSO.
        :param pulumi.Input[_builtins.str] sso_group_name: Name of the SSO userGroup.
        :param pulumi.Input[_builtins.bool] sso_linked: Whether sso is linked or not.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_emails: List of user emails in the UserGroup. Either provide list of users or list of user emails.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users: List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if externally_managed is not None:
            pulumi.set(__self__, "externally_managed", externally_managed)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if linked_sso_display_name is not None:
            pulumi.set(__self__, "linked_sso_display_name", linked_sso_display_name)
        if linked_sso_id is not None:
            pulumi.set(__self__, "linked_sso_id", linked_sso_id)
        if linked_sso_type is not None:
            pulumi.set(__self__, "linked_sso_type", linked_sso_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notification_configs is not None:
            pulumi.set(__self__, "notification_configs", notification_configs)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if sso_group_id is not None:
            pulumi.set(__self__, "sso_group_id", sso_group_id)
        if sso_group_name is not None:
            pulumi.set(__self__, "sso_group_name", sso_group_name)
        if sso_linked is not None:
            pulumi.set(__self__, "sso_linked", sso_linked)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if user_emails is not None:
            pulumi.set(__self__, "user_emails", user_emails)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="externallyManaged")
    def externally_managed(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the user group is externally managed.
        """
        return pulumi.get(self, "externally_managed")

    @externally_managed.setter
    def externally_managed(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "externally_managed", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="linkedSsoDisplayName")
    def linked_sso_display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the linked SSO.
        """
        return pulumi.get(self, "linked_sso_display_name")

    @linked_sso_display_name.setter
    def linked_sso_display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_sso_display_name", value)

    @_builtins.property
    @pulumi.getter(name="linkedSsoId")
    def linked_sso_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The SSO account ID that the user group is linked to.
        """
        return pulumi.get(self, "linked_sso_id")

    @linked_sso_id.setter
    def linked_sso_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_sso_id", value)

    @_builtins.property
    @pulumi.getter(name="linkedSsoType")
    def linked_sso_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of linked SSO.
        """
        return pulumi.get(self, "linked_sso_type")

    @linked_sso_type.setter
    def linked_sso_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "linked_sso_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notificationConfigs")
    def notification_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]]]:
        """
        List of notification settings.
        """
        return pulumi.get(self, "notification_configs")

    @notification_configs.setter
    def notification_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UsergroupNotificationConfigArgs']]]]):
        pulumi.set(self, "notification_configs", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="ssoGroupId")
    def sso_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the userGroup in SSO.
        """
        return pulumi.get(self, "sso_group_id")

    @sso_group_id.setter
    def sso_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sso_group_id", value)

    @_builtins.property
    @pulumi.getter(name="ssoGroupName")
    def sso_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the SSO userGroup.
        """
        return pulumi.get(self, "sso_group_name")

    @sso_group_name.setter
    def sso_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sso_group_name", value)

    @_builtins.property
    @pulumi.getter(name="ssoLinked")
    def sso_linked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether sso is linked or not.
        """
        return pulumi.get(self, "sso_linked")

    @sso_linked.setter
    def sso_linked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sso_linked", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="userEmails")
    def user_emails(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of user emails in the UserGroup. Either provide list of users or list of user emails.
        """
        return pulumi.get(self, "user_emails")

    @user_emails.setter
    def user_emails(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_emails", value)

    @_builtins.property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "users", value)


@pulumi.type_token("harness:platform/usergroup:Usergroup")
class Usergroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 externally_managed: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_id: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UsergroupNotificationConfigArgs', 'UsergroupNotificationConfigArgsDict']]]]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_linked: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_emails: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating a Harness User Group. Linking SSO providers with User Groups:

                The following fields need to be populated for LDAP SSO Providers:
            	
                - linked_sso_id
            	
                - linked_sso_display_name
            	
                - sso_group_id
            	
                - sso_group_name
            	
                - linked_sso_type
            	
                - sso_linked
            	
                The following fields need to be populated for SAML SSO Providers:
            	
                - linked_sso_id
            	
                - linked_sso_display_name
            	
                - sso_group_name
            	
                - sso_group_id // same as sso_group_name
            	
                - linked_sso_type
            	
                - sso_linked

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        sso_type_saml = harness.platform.Usergroup("sso_type_saml",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            linked_sso_id="linked_sso_id",
            externally_managed=False,
            users=["user_id"],
            notification_configs=[
                {
                    "type": "SLACK",
                    "slack_webhook_url": "https://google.com",
                },
                {
                    "type": "EMAIL",
                    "group_email": "email@email.com",
                    "send_email_to_all_users": True,
                },
                {
                    "type": "MSTEAMS",
                    "microsoft_teams_webhook_url": "https://google.com",
                },
                {
                    "type": "PAGERDUTY",
                    "pager_duty_key": "pagerDutyKey",
                },
            ],
            linked_sso_display_name="linked_sso_display_name",
            sso_group_id="sso_group_name",
            sso_group_name="sso_group_name",
            linked_sso_type="SAML",
            sso_linked=True)
        sso_type_ldap = harness.platform.Usergroup("sso_type_ldap",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            linked_sso_id="linked_sso_id",
            externally_managed=False,
            users=["user_id"],
            notification_configs=[
                {
                    "type": "SLACK",
                    "slack_webhook_url": "https://google.com",
                },
                {
                    "type": "EMAIL",
                    "group_email": "email@email.com",
                    "send_email_to_all_users": True,
                },
                {
                    "type": "MSTEAMS",
                    "microsoft_teams_webhook_url": "https://google.com",
                },
                {
                    "type": "PAGERDUTY",
                    "pager_duty_key": "pagerDutyKey",
                },
            ],
            linked_sso_display_name="linked_sso_display_name",
            sso_group_id="sso_group_id",
            sso_group_name="sso_group_name",
            linked_sso_type="LDAP",
            sso_linked=True)
        # Create user group by adding user emails
        example = harness.platform.Usergroup("example",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            linked_sso_id="linked_sso_id",
            externally_managed=False,
            user_emails=["user@email.com"],
            notification_configs=[
                {
                    "type": "SLACK",
                    "slack_webhook_url": "https://google.com",
                },
                {
                    "type": "EMAIL",
                    "group_email": "email@email.com",
                    "send_email_to_all_users": True,
                },
                {
                    "type": "MSTEAMS",
                    "microsoft_teams_webhook_url": "https://google.com",
                },
                {
                    "type": "PAGERDUTY",
                    "pager_duty_key": "pagerDutyKey",
                },
            ],
            linked_sso_display_name="linked_sso_display_name",
            sso_group_id="sso_group_name",
            sso_group_name="sso_group_name",
            linked_sso_type="SAML",
            sso_linked=True)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level user group

        ```sh
        $ pulumi import harness:platform/usergroup:Usergroup example <usergroup_id>
        ```

        Import org level user group

        ```sh
        $ pulumi import harness:platform/usergroup:Usergroup example <ord_id>/<usergroup_id>
        ```

        Import project level user group

        ```sh
        $ pulumi import harness:platform/usergroup:Usergroup example <org_id>/<project_id>/<usergroup_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] externally_managed: Whether the user group is externally managed.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] linked_sso_display_name: Name of the linked SSO.
        :param pulumi.Input[_builtins.str] linked_sso_id: The SSO account ID that the user group is linked to.
        :param pulumi.Input[_builtins.str] linked_sso_type: Type of linked SSO.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['UsergroupNotificationConfigArgs', 'UsergroupNotificationConfigArgsDict']]]] notification_configs: List of notification settings.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] sso_group_id: Identifier of the userGroup in SSO.
        :param pulumi.Input[_builtins.str] sso_group_name: Name of the SSO userGroup.
        :param pulumi.Input[_builtins.bool] sso_linked: Whether sso is linked or not.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_emails: List of user emails in the UserGroup. Either provide list of users or list of user emails.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users: List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UsergroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness User Group. Linking SSO providers with User Groups:

                The following fields need to be populated for LDAP SSO Providers:
            	
                - linked_sso_id
            	
                - linked_sso_display_name
            	
                - sso_group_id
            	
                - sso_group_name
            	
                - linked_sso_type
            	
                - sso_linked
            	
                The following fields need to be populated for SAML SSO Providers:
            	
                - linked_sso_id
            	
                - linked_sso_display_name
            	
                - sso_group_name
            	
                - sso_group_id // same as sso_group_name
            	
                - linked_sso_type
            	
                - sso_linked

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        sso_type_saml = harness.platform.Usergroup("sso_type_saml",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            linked_sso_id="linked_sso_id",
            externally_managed=False,
            users=["user_id"],
            notification_configs=[
                {
                    "type": "SLACK",
                    "slack_webhook_url": "https://google.com",
                },
                {
                    "type": "EMAIL",
                    "group_email": "email@email.com",
                    "send_email_to_all_users": True,
                },
                {
                    "type": "MSTEAMS",
                    "microsoft_teams_webhook_url": "https://google.com",
                },
                {
                    "type": "PAGERDUTY",
                    "pager_duty_key": "pagerDutyKey",
                },
            ],
            linked_sso_display_name="linked_sso_display_name",
            sso_group_id="sso_group_name",
            sso_group_name="sso_group_name",
            linked_sso_type="SAML",
            sso_linked=True)
        sso_type_ldap = harness.platform.Usergroup("sso_type_ldap",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            linked_sso_id="linked_sso_id",
            externally_managed=False,
            users=["user_id"],
            notification_configs=[
                {
                    "type": "SLACK",
                    "slack_webhook_url": "https://google.com",
                },
                {
                    "type": "EMAIL",
                    "group_email": "email@email.com",
                    "send_email_to_all_users": True,
                },
                {
                    "type": "MSTEAMS",
                    "microsoft_teams_webhook_url": "https://google.com",
                },
                {
                    "type": "PAGERDUTY",
                    "pager_duty_key": "pagerDutyKey",
                },
            ],
            linked_sso_display_name="linked_sso_display_name",
            sso_group_id="sso_group_id",
            sso_group_name="sso_group_name",
            linked_sso_type="LDAP",
            sso_linked=True)
        # Create user group by adding user emails
        example = harness.platform.Usergroup("example",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            linked_sso_id="linked_sso_id",
            externally_managed=False,
            user_emails=["user@email.com"],
            notification_configs=[
                {
                    "type": "SLACK",
                    "slack_webhook_url": "https://google.com",
                },
                {
                    "type": "EMAIL",
                    "group_email": "email@email.com",
                    "send_email_to_all_users": True,
                },
                {
                    "type": "MSTEAMS",
                    "microsoft_teams_webhook_url": "https://google.com",
                },
                {
                    "type": "PAGERDUTY",
                    "pager_duty_key": "pagerDutyKey",
                },
            ],
            linked_sso_display_name="linked_sso_display_name",
            sso_group_id="sso_group_name",
            sso_group_name="sso_group_name",
            linked_sso_type="SAML",
            sso_linked=True)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level user group

        ```sh
        $ pulumi import harness:platform/usergroup:Usergroup example <usergroup_id>
        ```

        Import org level user group

        ```sh
        $ pulumi import harness:platform/usergroup:Usergroup example <ord_id>/<usergroup_id>
        ```

        Import project level user group

        ```sh
        $ pulumi import harness:platform/usergroup:Usergroup example <org_id>/<project_id>/<usergroup_id>
        ```

        :param str resource_name: The name of the resource.
        :param UsergroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UsergroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 externally_managed: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_id: Optional[pulumi.Input[_builtins.str]] = None,
                 linked_sso_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UsergroupNotificationConfigArgs', 'UsergroupNotificationConfigArgsDict']]]]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_linked: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_emails: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UsergroupArgs.__new__(UsergroupArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["externally_managed"] = externally_managed
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["linked_sso_display_name"] = linked_sso_display_name
            __props__.__dict__["linked_sso_id"] = linked_sso_id
            __props__.__dict__["linked_sso_type"] = linked_sso_type
            __props__.__dict__["name"] = name
            __props__.__dict__["notification_configs"] = notification_configs
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["sso_group_id"] = sso_group_id
            __props__.__dict__["sso_group_name"] = sso_group_name
            __props__.__dict__["sso_linked"] = sso_linked
            __props__.__dict__["tags"] = tags
            __props__.__dict__["user_emails"] = user_emails
            __props__.__dict__["users"] = users
        super(Usergroup, __self__).__init__(
            'harness:platform/usergroup:Usergroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            externally_managed: Optional[pulumi.Input[_builtins.bool]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            linked_sso_display_name: Optional[pulumi.Input[_builtins.str]] = None,
            linked_sso_id: Optional[pulumi.Input[_builtins.str]] = None,
            linked_sso_type: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            notification_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UsergroupNotificationConfigArgs', 'UsergroupNotificationConfigArgsDict']]]]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            sso_group_id: Optional[pulumi.Input[_builtins.str]] = None,
            sso_group_name: Optional[pulumi.Input[_builtins.str]] = None,
            sso_linked: Optional[pulumi.Input[_builtins.bool]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            user_emails: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'Usergroup':
        """
        Get an existing Usergroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] externally_managed: Whether the user group is externally managed.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] linked_sso_display_name: Name of the linked SSO.
        :param pulumi.Input[_builtins.str] linked_sso_id: The SSO account ID that the user group is linked to.
        :param pulumi.Input[_builtins.str] linked_sso_type: Type of linked SSO.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['UsergroupNotificationConfigArgs', 'UsergroupNotificationConfigArgsDict']]]] notification_configs: List of notification settings.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] sso_group_id: Identifier of the userGroup in SSO.
        :param pulumi.Input[_builtins.str] sso_group_name: Name of the SSO userGroup.
        :param pulumi.Input[_builtins.bool] sso_linked: Whether sso is linked or not.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_emails: List of user emails in the UserGroup. Either provide list of users or list of user emails.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users: List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UsergroupState.__new__(_UsergroupState)

        __props__.__dict__["description"] = description
        __props__.__dict__["externally_managed"] = externally_managed
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["linked_sso_display_name"] = linked_sso_display_name
        __props__.__dict__["linked_sso_id"] = linked_sso_id
        __props__.__dict__["linked_sso_type"] = linked_sso_type
        __props__.__dict__["name"] = name
        __props__.__dict__["notification_configs"] = notification_configs
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["sso_group_id"] = sso_group_id
        __props__.__dict__["sso_group_name"] = sso_group_name
        __props__.__dict__["sso_linked"] = sso_linked
        __props__.__dict__["tags"] = tags
        __props__.__dict__["user_emails"] = user_emails
        __props__.__dict__["users"] = users
        return Usergroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="externallyManaged")
    def externally_managed(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the user group is externally managed.
        """
        return pulumi.get(self, "externally_managed")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="linkedSsoDisplayName")
    def linked_sso_display_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the linked SSO.
        """
        return pulumi.get(self, "linked_sso_display_name")

    @_builtins.property
    @pulumi.getter(name="linkedSsoId")
    def linked_sso_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The SSO account ID that the user group is linked to.
        """
        return pulumi.get(self, "linked_sso_id")

    @_builtins.property
    @pulumi.getter(name="linkedSsoType")
    def linked_sso_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Type of linked SSO.
        """
        return pulumi.get(self, "linked_sso_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notificationConfigs")
    def notification_configs(self) -> pulumi.Output[Optional[Sequence['outputs.UsergroupNotificationConfig']]]:
        """
        List of notification settings.
        """
        return pulumi.get(self, "notification_configs")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="ssoGroupId")
    def sso_group_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Identifier of the userGroup in SSO.
        """
        return pulumi.get(self, "sso_group_id")

    @_builtins.property
    @pulumi.getter(name="ssoGroupName")
    def sso_group_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the SSO userGroup.
        """
        return pulumi.get(self, "sso_group_name")

    @_builtins.property
    @pulumi.getter(name="ssoLinked")
    def sso_linked(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether sso is linked or not.
        """
        return pulumi.get(self, "sso_linked")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="userEmails")
    def user_emails(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of user emails in the UserGroup. Either provide list of users or list of user emails.
        """
        return pulumi.get(self, "user_emails")

    @_builtins.property
    @pulumi.getter
    def users(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of users in the UserGroup. Either provide list of users or list of user emails. (Should be null for SSO managed)
        """
        return pulumi.get(self, "users")

